/*******************************************************************************
*
* Program     : FarSync Flex Common Header
*
* File        : uss_cmn.h
*
* Description : FarSync Flex common header file, shared between oncard code and
*               Windows and Linux drivers.
*
*               NOTE: all parameters are in Little Endian format
*
* Modifications
*
* Date      Init   Details
*
* 27Nov2006 MJD    First Chinook Version
*
* Version 1.0.0  27Nov06  MJD  Created
* Version 1.0.1  31Jan07  MJD  Split USS_CMD_SECURE_MESSAGE into SEND_SECURE_MSG
*                              and RECV_SECURE_RSP - affects subsequent command
*                              numbering.
* Version 1.0.2  26Apr07  MJD  Added USS_CMD_SET/GET_LOOP_MODE &
*                              USS_CMD_GET_CLOCK_STATUS. 
* Version 1.0.3  02May07  MJD  Added USS_CMD_GET_CLOCK_RATE.
* Version 1.0.4  03May07  WEB  Move TERMINATION defs into fscmn
*                              Remove RXCLOCK defs since they are also defined
*                              in fscmn.h
* Version 1.0.5  19Nov07  MJD  Added monitorMode parameter to FLEX_SERCONF
*                              structure and update FLEX_SERCONF_VERSION to 2
* Version 1.0.6  23Jan07  MJD  Added extendedClocking, internalTxClock and
*                              internalRxClock to FLEX_SERCONF structure and
*                              update FLEX_SERCONF_VERSION to 3.
* Version 1.0.7  03Mar08  WEB  Change FLEX_TXRX_PREMABLE to be derived from
*                              FSCMN_TXRX_PREAMBLE
* Version 1.0.8  06Oct08  MJD  Added _FLEX_TXRX_PREAMBLE for Linux
* Version 1.0.9  23Feb09  MJD  Added preserveSignals parameter to FLEX_SERCONF,
*                              define USS_CMD_SET_MONITOR_MODE through
*                              USS_CMD_GET_PRESERVE_SIGNALS commands and update
*                              FLEX_SERCONF_VERSION to 5.
* Version 1.1.0  26Feb09  MJD  Added asyncReceiveMode parameter to FLEX_SERCONF,
*                              and update FLEX_SERCONF_VERSION to 6.
* Version 1.1.1  21Aug09  MJD  Change COM_FLOW_CONTROL_XXXX parameters to be 
*                              1, 2, 3 as per smc.h definitions used on T4E(+).
*                              Change made just before 1st release of Flex Async
* Version 1.1.2  05Jan10  MJD  Defined USS_CMD_INJECT_ERRORS command.
* Version 1.1.3  27Oct11  MJD  Added crcReset parameter to FLEX_SERCONF,
*                              define USS_CMD_SET_CRC_RESET and
*                              USS_CMD_GET_CRC_RESET commands and update
*                              FLEX_SERCONF_VERSION to 7. Add USS_CMD_SOFT_RESET
*                              command to allow soft reset of Flex after e.g.
*                              remote software update.
* Version 1.1.4  20Dec12  MJD  Added extendedConfig parameter to FLEX_SERCONF,
*                              define USS_CMD_SET_EXT_CONFIG,
*                              USS_CMD_GET_CAPABILITY_MASK,
*                              USS_CMD_GET_FEATURE_MASK, 
*                              USS_CMD_GET_EXT_CONFIG and USS_CMD_SEND_MARK
*                              commands and update FLEX_SERCONF_VERSION to 8.
* Version 1.1.5  02Jan13  MJD  Split EXT_CONFIG_DIV into EXT_CONFIG_RIV and
*                              EXT_CONFIG_TIV. 
* Version 1.1.6  13Jun13  BW   Added FLEX_SERCONF_EX structure and 
*                              Define new commands USS_CMD_SET_CONFIG_EX,
*                              	                   USS_CMD_GET_CONFIG_EX,
*                              	                   USS_CMD_STOP_BERT,
*                              	                   USS_CMD_RESET_BERT_COUNT
*                              Added structure FLEX_BERT_STATS
* Version 1.1.7  19Jun15  MJD  Added EXT_CONFIG_OIN definition
* Version 1.1.8  03Jan18  MJD  Add new command USS_CMD_SWITCH_FLASH for Flex V3.
* Version 1.1.9  02Mar20  MJD  Add new command USS_CMD_EXT_SRAM_TEST for Flex V3.
* Version 1.2.0  13Oct20  MJD  Ported to K2Ee, standardize data types
* Version 1.2.1  27Jan22  MJD  Added EXT_CONFIG_NITF
* Version 1.2.2  19Jun22  MJD  Added support for USS_CMD_SET_USER_CLOCK for K2Ee
* Version 1.2.3  11Apr23  MJD  Added EXT_CONFIG_RS485_CFG_VAL_MASK to signify
*                              other RS485 open/close pattern/flag bits valid
*******************************************************************************/

#ifndef INC_USS_CMN
#define INC_USS_CMN

// All user data frames transmitted/received to/from the FarSync Flex have an
// eight-byte preamble. Although the transmitter does not use all elements of
// the preamble, they are included to simplify loopback testing etc.

#include "fscmn.h"

#define RXDATA_STATUS 0x00
#define TXDATA_STATUS 0x10
#define SIGNAL_CHANGE 0x20
#define TXRX_ERROR    0x30
  
#define FLEX_TXRX_PREAMBLE FSCMN_TXRX_PREAMBLE
#define _FLEX_TXRX_PREAMBLE _FSCMN_TXRX_PREAMBLE
#define PFLEX_TXRX_PREAMBLE PFSCMN_TXRX_PREAMBLE

// USB Device Requests sent to the card via the default Control Pipe.

// When bmRequestType is Vendor; bRequest is defined below.
// wValue is a 16-bit parameter whose use varies by command.
// wIndex is a 16-bit parameter that usually directs the command to a specific
// port, it is sometimes used in conjunction with wValue to form a 32-bit
// parameter for some of the memory access commands.
// wLength is is 16-bit parameter that defines the amount of data associated
// with a command. Valid range is zero (no data) to 256 maximum (bytes).
// Data is a variable length block containing data specific to each command.

// command code

typedef enum _USS_COMMANDS {
  USS_CMD_GET_VERSION = 1,          // 0x01
  USS_CMD_READ_FLASH,               // 0x02
  USS_CMD_WRITE_FLASH,              // 0x03
  USS_CMD_ERASE_FLASH,              // 0x04

  USS_CMD_START_PORT,               // 0x05
  USS_CMD_STOP_PORT,                // 0x06
  USS_CMD_ABORT_PORT,               // 0x07

  USS_CMD_SET_CONFIG,               // 0x08
  USS_CMD_GET_CONFIG,               // 0x09

  USS_CMD_SET_SIGNALS,              // 0x0A
  USS_CMD_GET_SIGNALS,              // 0x0B

  USS_CMD_START_BREAK,              // 0x0C
  USS_CMD_STOP_BREAK,               // 0x0D

  USS_CMD_SEND_XON,                 // 0x0E
  USS_CMD_SEND_XOFF,                // 0x0F

  USS_CMD_RESET_STATS,              // 0x10

  USS_CMD_RESET_TIME,               // 0x11

  USS_CMD_FLUSH_BUFFERS,            // 0x12

  USS_CMD_SET_DEBUG_LEVEL,          // 0x13

  USS_CMD_SEND_SECURE_MSG,          // 0x14
  USS_CMD_RECV_SECURE_RSP,          // 0x15

  USS_CMD_SET_INTERFACE,            // 0x16
  USS_CMD_GET_INTERFACE,            // 0x17

  USS_CMD_SET_TERMINATION,          // 0x18
  USS_CMD_GET_TERMINATION,          // 0x19

  USS_CMD_SET_LINESPEED,            // 0x1A
  USS_CMD_GET_LINESPEED,            // 0x1B

  USS_CMD_SET_CLOCK_SOURCE,         // 0x1C
  USS_CMD_GET_CLOCK_SOURCE,         // 0x1D

  USS_CMD_SET_ENCODING,             // 0x1E
  USS_CMD_GET_ENCODING,             // 0x1F

  USS_CMD_SET_DATA_MODE,            // 0x20
  USS_CMD_GET_DATA_MODE,            // 0x21

  USS_CMD_SET_SYNC_CHAR,            // 0x22
  USS_CMD_GET_SYNC_CHAR,            // 0x23

  USS_CMD_SET_BIT_ORDER,            // 0x24
  USS_CMD_GET_BIT_ORDER,            // 0x25

  USS_CMD_SET_RXC_INVERT,           // 0x26
  USS_CMD_GET_RXC_INVERT,           // 0x27

  USS_CMD_SET_START_MODE,           // 0x28
  USS_CMD_GET_START_MODE,           // 0x29

  USS_CMD_SET_NUM_TX_BUFFER,        // 0x2A
  USS_CMD_GET_NUM_TX_BUFFER,        // 0x2B 

  USS_CMD_SET_NUM_RX_BUFFER,        // 0x2C
  USS_CMD_GET_NUM_RX_BUFFER,        // 0x2D

  USS_CMD_SET_SIZE_TX_BUFFER,       // 0x2E
  USS_CMD_GET_SIZE_TX_BUFFER,       // 0x2F

  USS_CMD_SET_SIZE_RX_BUFFER,       // 0x30
  USS_CMD_GET_SIZE_RX_BUFFER,       // 0x31

  USS_CMD_SET_DATA_BITS,            // 0x32
  USS_CMD_GET_DATA_BITS,            // 0x33

  USS_CMD_SET_PARITY,               // 0x34
  USS_CMD_GET_PARITY,               // 0x35

  USS_CMD_SET_STOP_BITS,            // 0x36
  USS_CMD_GET_STOP_BITS,            // 0x37

  USS_CMD_SET_FLOW_CONTROL,         // 0x38
  USS_CMD_GET_FLOW_CONTROL,         // 0x39

  USS_CMD_SET_RX_TIMEOUT_ENABLE,    // 0x3A
  USS_CMD_GET_RX_TIMEOUT_ENABLE,    // 0x3B

  USS_CMD_SET_RX_TIMEOUT_LENGTH,    // 0x3C
  USS_CMD_GET_RX_TIMEOUT_LENGTH,    // 0x3D

  USS_CMD_RESET_PORT_STATS,         // 0x3E
  USS_CMD_GET_PORT_STATS,           // 0x3F

  USS_CMD_SET_IDENTIFY_MODE,        // 0x40
  USS_CMD_GET_CARD_INFO,            // 0x41

  USS_CMD_RESET_USB_STATS,          // 0x42
  USS_CMD_GET_USB_STATS,            // 0x43

  USS_CMD_SET_LOOP_MODE,            // 0x44
  USS_CMD_GET_LOOP_MODE,            // 0x45

  USS_CMD_GET_CLOCK_STATUS,	        // 0x46
  USS_CMD_GET_CLOCK_RATE,           // 0x47

  USS_CMD_SET_MONITOR_MODE,         // 0x48
  USS_CMD_GET_MONITOR_MODE,         // 0x49

  USS_CMD_SET_EXTENDED_CLOCKING,    // 0x4A
  USS_CMD_GET_EXTENDED_CLOCKING,    // 0x4B

  USS_CMD_SET_INTERNAL_TX_CLOCK,    // 0x4C
  USS_CMD_GET_INTERNAL_TX_CLOCK,    // 0x4D

  USS_CMD_SET_INTERNAL_RX_CLOCK,    // 0x4E
  USS_CMD_GET_INTERNAL_RX_CLOCK,    // 0x4F

  USS_CMD_SET_ENABLE_NRZI_CLOCKING,	// 0x50
  USS_CMD_GET_ENABLE_NRZI_CLOCKING,	// 0x51

  USS_CMD_SET_XON_CHAR,             // 0x52
  USS_CMD_GET_XON_CHAR,             // 0x53

  USS_CMD_SET_XOFF_CHAR,            // 0x54
  USS_CMD_GET_XOFF_CHAR,            // 0x55

  USS_CMD_SET_PRESERVE_SIGNALS,     // 0x56
  USS_CMD_GET_PRESERVE_SIGNALS,     // 0x57

  USS_CMD_SET_ASYNC_RX_MODE,        // 0x58
  USS_CMD_GET_ASYNC_RX_MODE,        // 0x59

  USS_CMD_INJECT_ERRORS,            // 0x5A

  USS_CMD_SOFT_RESET,               // 0x5B

  USS_CMD_SET_CRC_RESET,            // 0x5C
  USS_CMD_GET_CRC_RESET,            // 0x5D

  USS_CMD_SET_EXT_CONFIG,           // 0x5E
  USS_CMD_GET_EXT_CONFIG,           // 0x5F

  USS_CMD_GET_CAPABILITY_MASK,      // 0x60
  USS_CMD_GET_FEATURE_MASK,         // 0x61

  USS_CMD_SEND_MARK,                // 0x62

  USS_CMD_SET_CONFIG_EX,            // 0x63
  USS_CMD_GET_CONFIG_EX,            // 0x64

  USS_CMD_STOP_BERT,                // 0x65
  USS_CMD_RESET_BERT_COUNT,         // 0x66

  USS_CMD_SWITCH_FLASH,             // 0x67

  USS_CMD_EXT_SRAM_TEST,			// 0x68

  USS_CMD_SET_USER_CLOCK,			// 0x69

  //  others to be added...

  USS_CMD_MAX                       // 0x0
} USS_COMMANDS;

// Port Configuration Structure

typedef struct
{
  #define FLEX_SERCONF_VERSION  8

  uint32_t uVersion;           // Version of this structure
  uint32_t iface;              // interface type
  uint32_t termination;        // interface termination
  uint32_t lineSpeed;          // data rate in bps
  uint32_t clock;              // clock source
  uint32_t encoding;           // data encoding
  uint32_t mode;               // data mode
  uint32_t syncChar;           // Monosync/Bisync sync characters
  uint32_t bitOrder;           // Tx/Rx MSB first
  uint32_t rxclock;            // receive clock inversion
  uint32_t start;              // tx and rx start
  uint32_t numTxBuffer;
  uint32_t numRxBuffer;
  uint32_t sizeTxBuffer;
  uint32_t sizeRxBuffer;
  uint32_t dataBits;           // async data bits
  uint32_t parity;             // async parity bits
  uint32_t stopbits;           // async stop bits
  uint32_t flowControl;        // async flow control
  uint32_t timeoutEnable;      // async timeout enable
  uint32_t timeoutLength;      // async timeout length
  uint32_t monitorMode;        // open port in monitor mode, when TRUE - added VERSION 2
  uint32_t extendedClocking;   // when TRUE, the following overrides clock parameter - added VERSION 3
  uint32_t internalTxClock;    // independent control over transmit clock, TRUE => internal
  uint32_t internalRxClock;    // independent control over receive  clock, TRUE => internal
  uint32_t enableNRZIClocking; // clocking provided with NRZI data when TRUE - added VERSION 4
  uint32_t xonchar;            // xon  character, 0 => default (ctrl-Q, 0x11)
  uint32_t xoffchar;           // xoff character, 0 => default (ctrl-S, 0x13)
  uint32_t preserveSignals;    // preserve signals on port closure, when TRUE - added VERSION 5
  uint32_t asyncReceiveMode;   // async specifies format of fifo rx data - added VERSION 6
  uint32_t crcReset;           // CRC initial value reset - added VERSION 7
  uint32_t extendedConfig;     // Extended Configuration - added VERSION 8
}FLEX_SERCONF, *PFLEX_SERCONF;

// Hardware BERT Configuration Structure
typedef struct
{
  #define FLEX_SERCONF_EX_VERSION  9

  uint32_t uVersion;           // Version of this structure
  uint32_t iface;              // interface type
  uint32_t termination;        // interface termination
  uint32_t lineSpeed;          // data rate in bps
  uint32_t clock;              // clock source
  uint32_t encoding;           // data encoding
  uint32_t mode;               // data mode
  uint32_t syncChar;           // Monosync/Bisync sync characters
  uint32_t bitOrder;           // Tx/Rx MSB first
  uint32_t rxclock;            // receive clock inversion
  uint32_t start;              // tx and rx start
  uint32_t numTxBuffer;
  uint32_t numRxBuffer;
  uint32_t sizeTxBuffer;
  uint32_t sizeRxBuffer;
  uint32_t dataBits;           // async data bits
  uint32_t parity;             // async parity bits
  uint32_t stopbits;           // async stop bits
  uint32_t flowControl;        // async flow control
  uint32_t timeoutEnable;      // async timeout enable
  uint32_t timeoutLength;      // async timeout length
  uint32_t monitorMode;        // open port in monitor mode, when TRUE - added VERSION 2
  uint32_t extendedClocking;   // when TRUE, the following overrides clock parameter - added VERSION 3
  uint32_t internalTxClock;    // independent control over transmit clock, TRUE => internal
  uint32_t internalRxClock;    // independent control over receive  clock, TRUE => internal
  uint32_t enableNRZIClocking; // clocking provided with NRZI data when TRUE - added VERSION 4
  uint32_t xonchar;            // xon  character, 0 => default (ctrl-Q, 0x11)
  uint32_t xoffchar;           // xoff character, 0 => default (ctrl-S, 0x13)
  uint32_t preserveSignals;    // preserve signals on port closure, when TRUE - added VERSION 5
  uint32_t asyncReceiveMode;   // async specifies format of fifo rx data - added VERSION 6
  uint32_t crcReset;           // CRC initial value reset           - added VERSION 7
  uint32_t extendedConfig;     // Extended Configuration            - added VERSION 8

  uint32_t enableBERT;         // Enable Hardware BERT when TRUE    - added VERSION 9
  uint32_t bertPattern;        // BERT Test Pattern                 - added VERSION 9
  uint32_t TestLength;         // BERT Test Length                  - added VERSION 9
  uint32_t BurstMode;          // BERT Test Burst Mode              - added VERSION 9
  uint32_t AutoInvert;         // BERT Test Auto Invert             - added VERSION 9
  uint32_t StopOnError;        // BERT Test Stop when Error happen  - added VERSION 9

}FLEX_SERCONF_EX, *PFLEX_SERCONF_EX;

// Card Information

typedef struct
{
#define FFCARDINFO_VERSION  1

  uint32_t uVersion;            // Version number of this structure
  
  uint8_t  szSerialNo[16];      // FarSync Flex serial number
  uint32_t uMajorRev;           // Major hardware revision number
  uint32_t uMinorRev;           // Minor hardware revision number
  uint32_t uBuildState;         // FarSync Flex build state
  uint32_t uCPUSpeed;           // ARM 7 CPU speed
  uint32_t uMode;               // Internal card mode
  
  uint32_t uSoftwareVersion;    // Version number of running code
  uint32_t uArmVersion;         // USS2828 CHIP_VERSION register
  uint32_t uflashManfId;        // Manufacturer ID of FLASH
  uint32_t uflashDevId;         // Device ID of FLASH
  uint32_t uSeroccoVersion;     // SEROCCO-M VER3..0 registers
  
  uint32_t spare[17];
} FLEX_CARD_INFO, *PFLEX_CARD_INFO;  // sizeof(FLEX_CARD_INFO) = 128

// USB statistics counters maintained by Flex hardware, modulo 65536

typedef struct
{
  uint32_t uRxPacketCounter;     // number of packets received by USB    (16-bit)
  uint32_t uPacketDropped;       // packets dropped by USB               (16-bit)
  uint32_t uCrcError;            // CRC errors in token or data packets  (16-bit)
  uint32_t uBitStuffError;       // bit stuff errors                     (16-bit)
  uint32_t uPidError;            // errors in PID fields                 (16-bit)
  uint32_t uFramingError;        // errors in SYNC and EOP fields        (16-bit)
  uint32_t uTxPacketCounter;     // number of packets transmitted by USB (16-bit)
  uint32_t uStatCounterOverflow; // overflows in previous counters       ( 8-bit)
}FLEX_USB_STATS, *PFLEX_USB_STATS;

// External SRAM and SEROCCO test results structure for Flex V3
// Used by USS_CMD_EXT_SRAM_TEST command (supported by firmware release >= 0.4.1.2)

typedef struct
{
	unsigned long  ulExtMemAddrBitTstErr;     // 0x0000 0000 => Test Passed, non zero => An failed (for A19...A0)
	unsigned short usExtMemDataFillTstErr;    // 0x0000 => Test Passed, non zero => n of 256 readbacks failed
	unsigned short usExtMem16BitW1TstErr;     // 0x0000 => Test Passed, non zero => Dn failed (for D15...D0)
	unsigned short usSerocco16BitW1TstErr;    // 0x0000 => Test Passed, non zero => Dn failed (for D15...D0)
	unsigned char  ucExtMemOddByteW1TstErr;   // 0x00 => Test Passed, non zero => Dn failed (for D7+8...D0+8)
	unsigned char  ucExtMemEvenByteW1TstErr;  // 0x00 => Test Passed, non zero => Dn failed (for D7...D0)
	unsigned char  ucSeroccoEvenByteW1TstErr; // 0x00 => Test Passed, non zero => Dn failed (for D7...D0)
	unsigned char  uc_spare_0;                //
	unsigned char  uc_spare_1;                //
	unsigned char  ucTestStatus;              // 0x00 => Test Completed, non-zero => Test Not Completed
}MEM_TEST, *PMEM_TEST;

// Configuration Parameter Defines

// Async data bits defines

#define COM_DATA_BITS_8       0
#define COM_DATA_BITS_7       1
#define COM_DATA_BITS_6       2
#define COM_DATA_BITS_5       3

#define COM_DATA_BITS_DEFAULT COM_DATA_BITS_8

// Async parity defines

#define COM_NO_PARITY         0
#define COM_ODD_PARITY        1
#define COM_EVEN_PARITY       2
#define COM_FORCE_PARITY_1    3
#define COM_FORCE_PARITY_0    4

#define COM_PARITY_DEFAULT COM_NO_PARITY

// Async stop bit defines

#define COM_STOP_BITS_1       0
#define COM_STOP_BITS_1_5     1
#define COM_STOP_BITS_2       2

#define COM_STOP_DEFAULT COM_STOP_BITS_1

// Async flow control defines

#define COM_FLOW_CONTROL_NONE     1
#define COM_FLOW_CONTROL_RTSCTS   2
#define COM_FLOW_CONTROL_XONXOFF  3

#define COM_FLOW_CONTROL_DEFAULT COM_FLOW_CONTROL_NONE

// Flush buffers defines

#define FLUSH_TX_BUFFERS 1
#define FLUSH_RX_BUFFERS 2

// Async timeout enable defines

#define COM_RX_TIMEOUT_DISABLE   0
#define COM_RX_TIMEOUT_ENABLE    1

#define COM_RX_TIMEOUT_DEFAULT COM_RX_TIMEOUT_DISABLE

// Async timeout length defines

// Loopback mode defines

#define FLEX_LOOP_NONE   0
#define FLEX_LOOP_USB    1
#define FLEX_LOOP_SERIAL 2

#define FLEX_LOOP_DEFAULT FLEX_LOOP_NONE

// Extended Configuration defines

#define EXT_CONFIG_NONE   0
#define EXT_CONFIG_RTT	  1
#define EXT_CONFIG_TTT    2
#define EXT_CONFIG_RIV    4
#define EXT_CONFIG_TIV    8

// EXT_CONFIG bits 5...4 are currently unused

#define EXT_CONFIG_OIN    0x40
#define EXT_CONFIG_NITF   0x80

// EXT_CONFIG bits 9...8 are currently unused

// Following bits added for RS485 Configuration on K2Ee/K4Ee/Flex V4
// Bit 10 set indicates following config bit are valid

#define EXT_CONFIG_RS485_CFG_VAL_MASK	0x00000400
#define EXT_CONFIG_RS485_CFG_VAL_SHIFT	10
#define EXT_CONFIG_PATTERN_TYPE_MASK	0x00000800
#define EXT_CONFIG_PATTERN_TYPE_SHIFT	11
#define EXT_CONFIG_OPEN_FLAGS_MASK		0x0000f000
#define EXT_CONFIG_OPEN_FLAGS_SHIFT		12
#define EXT_CONFIG_CLOSE_FLAGS_MASK		0x000f0000
#define EXT_CONFIG_CLOSE_FLAGS_SHIFT	16
#define EXT_CONFIG_OPEN_PATTERN_MASK	0x03f00000
#define EXT_CONFIG_OPEN_PATTERN_SHIFT	20
#define EXT_CONFIG_CLOSE_PATTERN_MASK	0xfc000000
#define EXT_CONFIG_CLOSE_PATTERN_SHIFT	26

#define EXT_CONFIG_DEFAULT EXT_CONFIG_NONE

// BERT Test Pattern defines
#define PATTERN_63			1
#define PATTERN_511			2
#define PATTERN_2047		3
#define PATTERN_2_15		4
#define PATTERN_2_20		5
#define PATTERN_2_23		6
#define PATTERN_QRSS		7
#define PATTERN_1_7			8
#define PATTERN_1_16		9
#define PATTERN_2_8  		10
#define PATTERN_3_24		11
#define PATTERN_ALT_1_0 13
#define PATTERN_FOX			14
#define PATTERN_MK			15
#define PATTERN_SP			16

/*****************************************************************************/
/* Structure for Hardware BERT stats.                         				 */
/*****************************************************************************/
typedef struct
{
  uint8_t version; 	 // Version number of stats structure

  uint8_t bertStatus; // bit field indicating state of STOP(bit2), RIV(bit1), LOS(bit0)
#define  STOP_BIT  0x04
#define  RIV_BIT   0x02
#define  LOS_BIT   0x01

  uint8_t UnusedByte0;
  uint8_t UnusedByte1;

  uint32_t millisecs;   // number of millisecs during which the following stats have been obtained

  // stats obtained during 'secs' period
  uint32_t bit_count;
  uint32_t block_count;
  uint32_t bit_errors;
  uint32_t block_errors;
  uint32_t es;
  uint32_t ses;
  uint32_t as;
} FLEX_BERT_STATS, *PFLEX_BERT_STATS;

#endif // INC_USS_CMN
